"""Create Memento Tables

Revision ID: 21f989b77c7c
Revises:
Create Date: 2024-11-05 19:56:09.734297

"""

from typing import Sequence, Union

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision: str = "21f989b77c7c"
down_revision: Union[str, None] = None
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "memento_conversation",
        sa.Column("agent", sa.String(), nullable=False),
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("uuid", sa.Uuid(), nullable=False),
        sa.Column("created_at", sa.DateTime(), nullable=False),
        sa.Column("updated_at", sa.DateTime(), nullable=True),
        sa.Column("archived", sa.Boolean(), nullable=False),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_index(
        op.f("ix_memento_conversation_uuid"),
        "memento_conversation",
        ["uuid"],
        unique=False,
    )
    op.create_table(
        "memento_message",
        sa.Column("conversation_id", sa.Integer(), nullable=False),
        sa.Column("role", sa.String(), nullable=False),
        sa.Column("content", sa.String(), nullable=True),
        sa.Column("tools", sa.String(), nullable=True),
        sa.Column("feedback", sa.Boolean(), nullable=True),
        sa.Column("origin_message_id", sa.Integer(), nullable=True),
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("uuid", sa.Uuid(), nullable=False),
        sa.Column("created_at", sa.DateTime(), nullable=False),
        sa.Column("updated_at", sa.DateTime(), nullable=True),
        sa.Column("archived", sa.Boolean(), nullable=False),
        sa.ForeignKeyConstraint(
            ["conversation_id"],
            ["memento_conversation.id"],
        ),
        sa.ForeignKeyConstraint(
            ["origin_message_id"],
            ["memento_message.id"],
        ),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_index(
        op.f("ix_memento_message_uuid"), "memento_message", ["uuid"], unique=False
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(op.f("ix_memento_message_uuid"), table_name="memento_message")
    op.drop_table("memento_message")
    op.drop_index(
        op.f("ix_memento_conversation_uuid"), table_name="memento_conversation"
    )
    op.drop_table("memento_conversation")
    # ### end Alembic commands ###
